==> bear_skin-7.x-2.1.tar.gz: bear_skin/theme-settings.php <==
<?php
/**
 * Implements hook_form_system_theme_settings_alter().
 *
 * @param $form
 *   Nested array of form elements that comprise the form.
 * @param $form_state
 *   A keyed array containing the current state of the form.
 */
function bear_skin_form_system_theme_settings_alter(&$form, &$form_state, $form_id = NULL) {
  // Work-around for a core bug affecting admin themes. See issue #943212.
  if (isset($form_id)) {
    return;
  }
  $form['bear_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Bear Theme Additional Options'),
  );

  // create an option to display the user menu
  $form['bear_options']['user_menu'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add User Menu to Header (Log In, Log Out etc).'),
    '#description' => t('Disable to use the block system'),
    '#default_value' => theme_get_setting('user_menu'),
  );

  // create an option for a sticky header
  $form['bear_options']['sticky_navbar'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add sticky navigation bar.'),
    '#description' => t('Let the header include a sticky navigation bar that sticks to the top when scrolling.'),
    '#default_value' => theme_get_setting('sticky_navbar'),
  );
  // if the sticky header is selected, allow height assignment
  $form['bear_options']['sticky_navbar_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Fade-in height for sticky navigation bar'),
    '#description' => t('If you selected a sticky navigation bar, at what scroll height should it appear?'),
    '#size' => 4,
    '#default_value' => theme_get_setting('sticky_navbar_height'),
    '#states' => array(
      'visible' => array(
        ':input[name="sticky_navbar"]' => array('checked', TRUE)
      )
    )
  );

  // create an option for sticky footers
  $form['bear_options']['sticky_footer'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add sticky footer.'),
    '#description' => t('More info about sticky footer <a href="http://www.cssstickyfooter.com/" target="_blank">here</a><br />
      You can change these settings in the the sticky-footer.css file located in the css folder.'),
    '#default_value' => theme_get_setting('sticky_footer'),
  );


  // Create the form using Forms API: http://api.drupal.org/api/7

  /* -- Delete this line if you want to use this setting
  $form['STARTERKIT_example'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('STARTERKIT sample setting'),
    '#default_value' => theme_get_setting('STARTERKIT_example'),
    '#description'   => t("This option doesn't do anything; it's just an example."),
  );
  // */

  // Remove some of the base theme's settings.
  /* -- Delete this line if you want to turn off this setting.
  unset($form['themedev']['zen_wireframes']); // We don't need to toggle wireframes on this site.
  // */

  // We are editing the $form in place, so we don't need to return anything.
}

==> bear_skin-7.x-3.7.tar.gz: bear_skin/theme-settings.php <==
<?php
/**
 * Implements hook_form_system_theme_settings_alter().
 *
 * @param $form
 *   Nested array of form elements that comprise the form.
 * @param $form_state
 *   A keyed array containing the current state of the form.
 */
function bear_skin_form_system_theme_settings_alter(&$form, &$form_state, $form_id = NULL) {
  // Work-around for a core bug affecting admin themes. See issue #943212.
  if (isset($form_id)) {
    return;
  }
  $form['bear_options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Bear Theme Additional Options'),
  );

  // create an option to display the user menu
  $form['bear_options']['main_layout'] = array(
    '#type' => 'radios',
    '#title' => t('General Layout'),
    '#description' => t('This option will allow you to pick between a full width (fluid) layout (for background, banners etc, content still has max width) and fixed layout.'),
    '#options' => array(
      'fluid' => t('Fluid'),
      'fixed' => t('Fixed'),
    ),
    '#default_value' => theme_get_setting('main_layout'),
  );

  // create an option to display the user menu
  $form['bear_options']['user_menu'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add User Menu to Header (Log In, Log Out etc).'),
    '#description' => t('Disable to use the block system'),
    '#default_value' => theme_get_setting('user_menu'),
  );

  // create an option for sticky footers
  $form['bear_options']['sticky_footer'] = array(
    '#type' => 'checkbox',
    '#title' => t('Add sticky footer.'),
    '#description' => t('More info about sticky footer <a href="http://www.cssstickyfooter.com/" target="_blank">here</a><br />
      You can change these settings in the the sticky-footer.css file located in the css folder.'),
    '#default_value' => theme_get_setting('sticky_footer'),
  );
}
